@@ -1,4 +1,4 @@
-import json, base64, os, requests, time, pafy, sys
+import json, base64, os, requests, time, pafy, sys, subprocess
 from rich.console import Console
 from rich.columns import Columns
 from rich.table import Table
@@ -86,7 +86,7 @@ class spotify_downloader():
         urls = []
         for key in tracks.keys():
             try:
-                got_url = (key+"+"+tracks[key]).replace(' ','+')
+                got_url = (key+"+lyrics+"+tracks[key]).replace(' ','+')
                 print(f"Fetching the details of {key} - {tracks[key]}")
                 urls.append(self.ytd.get_url(got_url)[0])
             except Exception as e:
@@ -163,7 +163,10 @@ class spotify_downloader():
         z = input("\tEnter\n\tf - flac\n\tany key - mp3 : ")
 
         for i,j,k in zip(urls, alburl, sponame):
-            os.system("cls")
+            if os.name == "nt":
+                os.system("cls")
+            elif os.name == "posix":
+                os.system("clear")
             Console().print("[bold][green]Downloaded songs:[/green][/bold]")
             Console().print(Columns([Panel(''.join(list(''.join(iz + '\n' * (N % 3 == 2) for N, iz in enumerate([ii+" " for ii in user.split()]))))+"\n[b][green]Downloaded[/green][/b]", expand=True) for user in os.listdir()]))
             self.ytd.download_song(i, j, k, z)
@@ -173,6 +176,7 @@ class spotify_downloader():
         
         self.get_json()
         sponame = []
+        print("\n\tConnecting to spotify...\n")
         sp = self.get_credentials()
         plLink = input("\nEnter the Spotify playlist/album URL: ")
         plName = input("\nGive a name to your playlist: ")
